@@ -8,7 +8,9 @@
     :license: Simplified BSD License, see LICENSE.txt for more details.
 """
 
-from flask import Blueprint
+from passlib.context import CryptContext
+
+from flask import Blueprint, current_app
 from flask_login import LoginManager, UserMixin as LoginUserMixin
 from flask_user.db_interfaces import DBInterface
 
@@ -20,7 +22,7 @@ from . import tokens
 from . import translations
 from . import views
 
-__version__ = '0.4.0'
+__version__ = '0.4.1'
 
 # Enable the following: from flask.ext.user import current_user
 from flask_login import current_user
@@ -32,8 +34,8 @@ def _user_loader(user_id):
     """
     Flask-Login helper function to load user by user_id
     """
-    user_manager = current_app.user_manager
-    return user_manager.db_adapter.find_user_by_id(user_id=user_id)
+    um = current_app.user_manager
+    return um.db_adapter.find_user_by_id(user_id=user_id)
 
 def _flask_user_context_processor():
     """
@@ -42,7 +44,7 @@ def _flask_user_context_processor():
     return dict(user_manager=current_app.user_manager)
 
 
-class UserManager():
+class UserManager(object):
     """
     This is the Flask-User object that manages the User management process.
     """
@@ -66,14 +68,14 @@ class UserManager():
                 login_view_function=views.login,
                 logout_view_function=views.logout,
                 register_view_function=views.register,
-                resend_confirmation_email_view_function = views.resend_confirmation_email,
+                resend_confirm_email_view_function = views.resend_confirm_email,
                 reset_password_view_function = views.reset_password,
                 unauthenticated_view_function = views.unauthenticated,
                 unauthorized_view_function = views.unauthorized,
                 # Misc
                 login_manager=LoginManager(),
                 token_manager=tokens.TokenManager(),
-                password_crypt_context=passwords.crypt_context,
+                password_crypt_context=None,
                 ):
         """
         Initialize the UserManager with custom or built-in attributes
@@ -98,7 +100,7 @@ class UserManager():
         self.login_view_function = login_view_function
         self.logout_view_function = logout_view_function
         self.register_view_function = register_view_function
-        self.resend_confirmation_email_view_function = resend_confirmation_email_view_function
+        self.resend_confirm_email_view_function = resend_confirm_email_view_function
         self.reset_password_view_function = reset_password_view_function
         self.unauthenticated_view_function = unauthenticated_view_function
         self.unauthorized_view_function = unauthorized_view_function
@@ -114,21 +116,28 @@ class UserManager():
         """
         Initialize app.user_manager.
         """
+        # Bind Flask-USER to app
         app.user_manager = self
 
-        # Initialize Translations
-        app.jinja_env.install_gettext_callables(
-                translations.gettext,
-                translations.ngettext,
-                newstyle=True
-                )
-
-        # Set default app.config settings, but only if they have not been set before
+        # Set defaults for undefined settings
         settings.set_default_settings(self, app.config)
 
-        # Verify config combinations. Produce a helpful error messages for invalid combinations.
+        # Make sure the settings are valid -- raise ConfigurationError if not
         settings.check_settings(self)
 
+        # Initialize Translations -- Only if Flask-Babel has been installed
+        if hasattr(app.jinja_env, 'install_gettext_callables'):
+            app.jinja_env.install_gettext_callables(
+                    translations.gettext,
+                    translations.ngettext,
+                    newstyle=True
+                    )
+
+        # Create password_crypt_context if needed
+        if not self.password_crypt_context:
+            self.password_crypt_context = CryptContext(
+                    schemes=[app.config['USER_PASSWORD_HASH']])
+
         # Setup Flask-Login
         self.setup_login_manager(app)
 
@@ -147,8 +156,6 @@ class UserManager():
 
     def setup_login_manager(self, app):
         _ = translations.gettext
-        self.lm.login_message = _('Please Sign in to access this page.')
-        self.lm.login_message_category = 'error'
         self.lm.login_view = 'user.login'
         self.lm.user_loader(_user_loader)
         #login_manager.token_loader(_token_loader)
@@ -158,7 +165,7 @@ class UserManager():
         # Add URL Routes
         if self.enable_confirm_email:
             app.add_url_rule(self.confirm_email_url, 'user.confirm_email', self.confirm_email_view_function)
-            app.add_url_rule(self.resend_confirmation_email_url, 'user.resend_confirmation_email', self.resend_confirmation_email_view_function)
+            app.add_url_rule(self.resend_confirm_email_url, 'user.resend_confirm_email', self.resend_confirm_email_view_function)
         if self.enable_change_password:
             app.add_url_rule(self.change_password_url, 'user.change_password', self.change_password_view_function, methods=['GET', 'POST'])
         if self.enable_change_username:
@@ -173,7 +180,20 @@ class UserManager():
         # We can not define 'user.unauthenticated' here because it clashes with 'user.login'
         # We can not define 'user.unauthorized' here because it clashes with 'home_page'
 
+    def generate_password_hash(self, password):
+        return passwords.hash_password(self, password)
 
+    def hash_password(self, password):
+        return passwords.hash_password(self, password)
+
+    def verify_password(self, password, hashed_password):
+        return passwords.verify_password(self, password, hashed_password)
+
+    def generate_token(self, user_id):
+        return self.token_manager.generate_token(user_id)
+
+    def verify_token(self, token, expiration_in_seconds):
+        return self.token_manager.verify_token(token, expiration_in_seconds)
 
 class UserMixin(LoginUserMixin):
     """
