@@ -30,6 +30,13 @@ class DBInterface(object):
     def find_user_by_username(self, username): # pragma: no cover
         raise NotImplementedError('DBInterface.find_user_by_username() has not been implemented')
 
+    def set_object_fields(self, object, **kwargs):
+        for key,value in kwargs.items():
+            if hasattr(object, key):
+                setattr(object, key, value)
+            else:
+                raise KeyError("Object '%s' has no field '%s'." % (type(object), key))
+
     def email_is_available(self, new_email):
         """
         Return True if new_email does not exist.
@@ -51,9 +58,6 @@ class DBInterface(object):
         # See if new_username is available
         return new_username==old_username or self.find_user_by_username(new_username)==None
 
-    def verify_reset_password_token(self, user, token):
-        return user.reset_password_token == token
-
     # def get_email(self, user):
     #     return user.email
 
@@ -86,7 +90,7 @@ class SQLAlchemyAdapter(DBInterface):
 
     def confirm_email(self, object_id):
         """
-        Mark the user record as active and sets email_confirmed_at to utcnow().
+        Mark the user record as active and sets confirmed_at to utcnow().
         object_id can either be a user_id or an email_id for the multiple_emails_per_user feature
         """
         if not self.EmailClass:
@@ -94,26 +98,30 @@ class SQLAlchemyAdapter(DBInterface):
             if user:
                 if not user.active:
                     user.active = True
-                    if hasattr(user, 'email_confirmed_at'):
-                        user.email_confirmed_at = datetime.utcnow()
+                    if hasattr(user, 'confirmed_at'):
+                        user.confirmed_at = datetime.utcnow()
                     self.db.session.commit()
             else:                                               # pragma: no cover
                 assert False, "Invalid user id "+str(object_id)
-            return (user.id, None)
         else:
             raise NotImplementedError   # TODO:
+        return user
 
-    def set_username(self, user, username):
-        user.username = username
+    def set_object_fields(self, object, **kwargs):
+        super(SQLAlchemyAdapter, self).set_object_fields(object, **kwargs)
         self.db.session.commit()
 
-    def set_password(self, user, hashed_password):
-        user.password = hashed_password
-        self.db.session.commit()
-
-    def set_reset_password_token(self, user, token):
-        user.reset_password_token = token
-        self.db.session.commit()
+    # def set_username(self, user, username):
+    #     user.username = username
+    #     self.db.session.commit()
+    #
+    # def set_password(self, user, hashed_password):
+    #     user.password = hashed_password
+    #     self.db.session.commit()
+    #
+    # def set_reset_password_token(self, user, token):
+    #     user.reset_password_token = token
+    #     self.db.session.commit()
 
     def find_user_by_id(self, user_id):
         return self.UserClass.query.filter(self.UserClass.id==user_id).first()
